@@ -473,7 +473,9 @@ class Database(object):
     def removeCallbacks(self, __id, close=True):
         # Wake up pending callbacks
         for cb in self._changesCBs[__id]:
-            cb(None, viewID=__id)
+            if cb is not None and not isinstance(cb, (str, unicode)):
+                # Fixme!!
+                cb(None, viewID=__id)
 
         del self._changesCBs[__id]
         del self._changesRunning[__id] 
